bt_socket_l2cap_le_connection_s class final

@ingroup CAPI_NETWORK_BLUETOOTH_SOCKET_MODULE @brief L2CAP CoC connection data used for exchanging data between Bluetooth devices. @since_tizen 7.0

@see bt_socket_l2cap_channel_connection_state_changed_cb()

Inheritance
Implemented types
Available extensions

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
local_role int
< The local device role in this connection
getter/setter pair
psm int
< The psm of the connected socket
getter/setter pair
remote_address Pointer<Char>
< The remote device address
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
server_fd int
< The file descriptor of the server socket or -1 for client connection
getter/setter pair
socket_fd int
< The file descriptor of connected socket
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited