peripheral_gpio_direction_e class abstract

@brief Enumeration of GPIO direction options. @since_tizen 4.0

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

PERIPHERAL_GPIO_DIRECTION_IN → const int
< Input Mode
PERIPHERAL_GPIO_DIRECTION_OUT_INITIALLY_HIGH → const int
< Output mode with high value
PERIPHERAL_GPIO_DIRECTION_OUT_INITIALLY_LOW → const int
< Output mode with low value