tts_service_state_changed_cb typedef

@brief Called when the state of TTS service is changed. @since_tizen 7.0 @remarks The @a tts handle should not be destroyed in the callback. @paramin tts The TTS handle, the same handle for which the callback was set. @paramin previous The previous state of TTS service @paramin current The current state of TTS service @paramin user_data The user data passed from the callback registration function @pre An application registers this callback using tts_set_service_state_changed_cb() to detect changing state of TTS service. @see tts_set_service_state_changed_cb() @see tts_unset_service_state_changed_cb()

Implementation

typedef tts_service_state_changed_cb
    = ffi.Pointer<ffi.NativeFunction<tts_service_state_changed_cbFunction>>;