tts_service_state_e class abstract

@brief Enumeration for service state. @since_tizen 7.0

Constructors

tts_service_state_e()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

TTS_SERVICE_STATE_BLOCKED → const int
< 'Blocked' state (Since 8.0)
TTS_SERVICE_STATE_NONE → const int
< 'None' state (Since 8.0)
TTS_SERVICE_STATE_PLAYING → const int
< 'Playing' state
TTS_SERVICE_STATE_READY → const int
< 'Ready' state
TTS_SERVICE_STATE_SYNTHESIZING → const int
< 'Synthesizing' state