mv_inference_facial_landmark_detected_cb typedef
@brief Called when facial landmarks in @a source are detected. @details This type callback is invoked each time when mv_inference_facial_landmark_detect() is called to provide the results of the landmarks detection.
@since_tizen 5.5 @remarks The @a locations should not be released by app. They can be used only in the callback. The number of elements in @a locations is equal to @a number_of_landmarks.
@paramin source The handle to the source of the media where
landmarks were detected. @a source is the same object
for which mv_inference_facial_landmark_detect() was called.
It should be released by calling mv_destroy_source()
when it's not needed anymore.
@paramin number_of_landmarks The number of landmarks
@paramin locations Locations of the detected facial landmarks.
@paramin user_data The user data passed from callback invoking code
@pre Call mv_inference_face_detect() function to perform detection of the faces in @a source and to invoke this callback as a result
@see mv_inference_face_detect()
Implementation
typedef mv_inference_facial_landmark_detected_cb = ffi.Pointer<
ffi.NativeFunction<mv_inference_facial_landmark_detected_cbFunction>>;