recorder_state_e class abstract
@brief Enumeration for recorder states. @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- RECORDER_STATE_CREATED → const int
- < Recorder is created, but not prepared
- RECORDER_STATE_NONE → const int
- < Recorder is not created
- RECORDER_STATE_PAUSED → const int
- < Recorder is paused while recording media
- RECORDER_STATE_READY → const int
- < Recorder is ready to record \n In case of video recorder, preview display will be shown
- RECORDER_STATE_RECORDING → const int
- < Recorder is recording media